==> openshift-model-hive-6.9.0-sources.jar: io/fabric8/openshift/api/model/hive/agent/v1/BareMetalPlatformFluent.java <==
package io.fabric8.openshift.api.model.hive.agent.v1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class BareMetalPlatformFluent<A extends BareMetalPlatformFluent<A>> extends BaseFluent<A>{
  public BareMetalPlatformFluent() {
  }
  
  public BareMetalPlatformFluent(BareMetalPlatform instance) {
    this.copyInstance(instance);
  }
  private LabelSelectorBuilder agentSelector;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(BareMetalPlatform instance) {
    instance = (instance != null ? instance : new BareMetalPlatform());
  
    if (instance != null) {
        this.withAgentSelector(instance.getAgentSelector());
        this.withAgentSelector(instance.getAgentSelector());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public LabelSelector buildAgentSelector() {
    return this.agentSelector!=null ?this.agentSelector.build():null;
  }
  
  public A withAgentSelector(LabelSelector agentSelector) {
    _visitables.get("agentSelector").remove(this.agentSelector);
    if (agentSelector!=null){ this.agentSelector= new LabelSelectorBuilder(agentSelector); _visitables.get("agentSelector").add(this.agentSelector);} else { this.agentSelector = null; _visitables.get("agentSelector").remove(this.agentSelector); } return (A) this;
  }
  
  public boolean hasAgentSelector() {
    return this.agentSelector != null;
  }
  
  public AgentSelectorNested<A> withNewAgentSelector() {
    return new AgentSelectorNested(null);
  }
  
  public AgentSelectorNested<A> withNewAgentSelectorLike(LabelSelector item) {
    return new AgentSelectorNested(item);
  }
  
  public AgentSelectorNested<A> editAgentSelector() {
    return withNewAgentSelectorLike(java.util.Optional.ofNullable(buildAgentSelector()).orElse(null));
  }
  
  public AgentSelectorNested<A> editOrNewAgentSelector() {
    return withNewAgentSelectorLike(java.util.Optional.ofNullable(buildAgentSelector()).orElse(new LabelSelectorBuilder().build()));
  }
  
  public AgentSelectorNested<A> editOrNewAgentSelectorLike(LabelSelector item) {
    return withNewAgentSelectorLike(java.util.Optional.ofNullable(buildAgentSelector()).orElse(item));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BareMetalPlatformFluent that = (BareMetalPlatformFluent) o;
    if (!java.util.Objects.equals(agentSelector, that.agentSelector)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(agentSelector,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (agentSelector != null) { sb.append("agentSelector:"); sb.append(agentSelector + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class AgentSelectorNested<N> extends LabelSelectorFluent<AgentSelectorNested<N>> implements Nested<N>{
    AgentSelectorNested(LabelSelector item) {
      this.builder = new LabelSelectorBuilder(this, item);
    }
    LabelSelectorBuilder builder;
    
    public N and() {
      return (N) BareMetalPlatformFluent.this.withAgentSelector(builder.build());
    }
    
    public N endAgentSelector() {
      return and();
    }
    
  
  }

}

==> openshift-model-hive-6.9.1-sources.jar: io/fabric8/openshift/api/model/hive/agent/v1/BareMetalPlatformFluent.java <==
package io.fabric8.openshift.api.model.hive.agent.v1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class BareMetalPlatformFluent<A extends BareMetalPlatformFluent<A>> extends BaseFluent<A>{
  public BareMetalPlatformFluent() {
  }
  
  public BareMetalPlatformFluent(BareMetalPlatform instance) {
    this.copyInstance(instance);
  }
  private LabelSelectorBuilder agentSelector;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(BareMetalPlatform instance) {
    instance = (instance != null ? instance : new BareMetalPlatform());
    if (instance != null) {
          this.withAgentSelector(instance.getAgentSelector());
          this.withAgentSelector(instance.getAgentSelector());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public LabelSelector buildAgentSelector() {
    return this.agentSelector != null ? this.agentSelector.build() : null;
  }
  
  public A withAgentSelector(LabelSelector agentSelector) {
    this._visitables.remove(this.agentSelector);
    if (agentSelector != null) {
        this.agentSelector = new LabelSelectorBuilder(agentSelector);
        this._visitables.get("agentSelector").add(this.agentSelector);
    } else {
        this.agentSelector = null;
        this._visitables.get("agentSelector").remove(this.agentSelector);
    }
    return (A) this;
  }
  
  public boolean hasAgentSelector() {
    return this.agentSelector != null;
  }
  
  public AgentSelectorNested<A> withNewAgentSelector() {
    return new AgentSelectorNested(null);
  }
  
  public AgentSelectorNested<A> withNewAgentSelectorLike(LabelSelector item) {
    return new AgentSelectorNested(item);
  }
  
  public AgentSelectorNested<A> editAgentSelector() {
    return withNewAgentSelectorLike(java.util.Optional.ofNullable(buildAgentSelector()).orElse(null));
  }
  
  public AgentSelectorNested<A> editOrNewAgentSelector() {
    return withNewAgentSelectorLike(java.util.Optional.ofNullable(buildAgentSelector()).orElse(new LabelSelectorBuilder().build()));
  }
  
  public AgentSelectorNested<A> editOrNewAgentSelectorLike(LabelSelector item) {
    return withNewAgentSelectorLike(java.util.Optional.ofNullable(buildAgentSelector()).orElse(item));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BareMetalPlatformFluent that = (BareMetalPlatformFluent) o;
    if (!java.util.Objects.equals(agentSelector, that.agentSelector)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(agentSelector,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (agentSelector != null) { sb.append("agentSelector:"); sb.append(agentSelector + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class AgentSelectorNested<N> extends LabelSelectorFluent<AgentSelectorNested<N>> implements Nested<N>{
    AgentSelectorNested(LabelSelector item) {
      this.builder = new LabelSelectorBuilder(this, item);
    }
    LabelSelectorBuilder builder;
    
    public N and() {
      return (N) BareMetalPlatformFluent.this.withAgentSelector(builder.build());
    }
    
    public N endAgentSelector() {
      return and();
    }
    
  
  }

}
